@@ -31,7 +31,7 @@ import socket
 from telnetlib import Telnet
 from typing import Any, Dict, List, Optional
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 __all__ = ['PyNUT3Error', 'PyNUT3Client']
 
 _LOGGER = logging.getLogger(__name__)
@@ -40,8 +40,6 @@ _LOGGER = logging.getLogger(__name__)
 class PyNUT3Error(Exception):
     """Base class for custom exceptions.
     """
-    # pylint: disable=unnecessary-pass
-    pass
 
 
 class PyNUT3Client:
